package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.cryptopro.ECGOST3410NamedCurves;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.sec.ECPrivateKeyStructure;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x9.X962Parameters;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.crypto.params.ECDomainParameters;
import cn.com.infosec.crypto.params.ECPrivateKeyParameters;
import cn.com.infosec.jce.interfaces.ECPointEncoder;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import cn.com.infosec.jce.spec.ECNamedCurveSpec;
import cn.com.infosec.jce.spec.ECPrivateKeySpec;
import cn.com.infosec.math.ec.ECCurve;
import java.math.BigInteger;
import java.security.interfaces.ECPrivateKey;
import java.security.spec.ECParameterSpec;
import java.security.spec.ECPoint;
import java.security.spec.EllipticCurve;
import java.util.Enumeration;

public class JCEECPrivateKey implements ECPrivateKey, cn.com.infosec.jce.interfaces.ECPrivateKey, PKCS12BagAttributeCarrier, ECPointEncoder {
   private String algorithm;
   private BigInteger d;
   private ECParameterSpec ecSpec;
   private boolean withCompression;
   private PKCS12BagAttributeCarrier attrCarrier;

   protected JCEECPrivateKey() {
      JCEECPrivateKey var10000 = this;
      super();
      this.algorithm = "EC";
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JCEECPrivateKey(ECPrivateKey key) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.d = key.getS();
      this.algorithm = key.getAlgorithm();
      this.ecSpec = key.getParams();
   }

   JCEECPrivateKey(String algorithm, ECPrivateKeySpec spec) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.algorithm = algorithm;
      this.d = spec.getD();
      if (spec.getParams() != null) {
         this.ecSpec = EC5Util.convertSpec(EC5Util.convertCurve(spec.getParams().getCurve(), spec.getParams().getSeed()), spec.getParams());
      } else {
         this.ecSpec = null;
      }

   }

   JCEECPrivateKey(String algorithm, java.security.spec.ECPrivateKeySpec spec) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.algorithm = algorithm;
      this.d = spec.getS();
      this.ecSpec = spec.getParams();
   }

   JCEECPrivateKey(String algorithm, JCEECPrivateKey key) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.algorithm = algorithm;
      this.d = key.d;
      this.ecSpec = key.ecSpec;
      this.withCompression = key.withCompression;
      this.attrCarrier = key.attrCarrier;
   }

   JCEECPrivateKey(String algorithm, ECPrivateKeyParameters params, ECParameterSpec spec) {
      String var10004 = algorithm;
      super();
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      ECDomainParameters algorithm1 = params.getParameters();
      this.algorithm = var10004;
      this.d = params.getD();
      if (spec == null) {
         JCEECPrivateKey var10000 = this;
         EllipticCurve var4 = EC5Util.convertCurve(algorithm1.getCurve(), algorithm1.getSeed());
         EllipticCurve var10003 = var4;
         ECDomainParameters var9 = algorithm1;
         ECPoint var5;
         var5 = new ECPoint.<init>(algorithm1.getG().getX().toBigInteger(), algorithm1.getG().getY().toBigInteger());
         BigInteger algorithm2 = algorithm1.getN();
         int params1 = var9.getH().intValue();
         var10000.ecSpec = new ECParameterSpec(var10003, var5, algorithm2, params1);
      } else {
         this.ecSpec = spec;
      }

   }

   JCEECPrivateKey(String algorithm, ECPrivateKeyParameters params, cn.com.infosec.jce.spec.ECParameterSpec spec) {
      String var10004 = algorithm;
      super();
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      ECDomainParameters algorithm1 = params.getParameters();
      this.algorithm = var10004;
      this.d = params.getD();
      EllipticCurve var4;
      ECPoint var5;
      BigInteger algorithm2;
      int params1;
      JCEECPrivateKey var10000;
      EllipticCurve var10003;
      if (spec == null) {
         var10000 = this;
         var4 = EC5Util.convertCurve(algorithm1.getCurve(), algorithm1.getSeed());
         var10003 = var4;
         ECDomainParameters var9 = algorithm1;
         var5 = new ECPoint.<init>(algorithm1.getG().getX().toBigInteger(), algorithm1.getG().getY().toBigInteger());
         algorithm2 = algorithm1.getN();
         params1 = var9.getH().intValue();
         var10000.ecSpec = new ECParameterSpec(var10003, var5, algorithm2, params1);
      } else {
         var10000 = this;
         var4 = EC5Util.convertCurve(spec.getCurve(), spec.getSeed());
         var10003 = var4;
         var5 = new ECPoint.<init>(spec.getG().getX().toBigInteger(), spec.getG().getY().toBigInteger());
         algorithm2 = spec.getN();
         params1 = spec.getH().intValue();
         var10000.ecSpec = new ECParameterSpec(var10003, var5, algorithm2, params1);
      }

   }

   JCEECPrivateKey(String algorithm, ECPrivateKeyParameters params) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.algorithm = algorithm;
      this.d = params.getD();
      this.ecSpec = null;
   }

   JCEECPrivateKey(PrivateKeyInfo info) {
      this.algorithm = "EC";
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      X962Parameters var2;
      X962Parameters var10000 = var2 = new X962Parameters;
      var10000.<init>((DERObject)info.getAlgorithmId().getParameters());
      X9ECParameters var3;
      BigInteger var12;
      if (var10000.isNamedCurve()) {
         EllipticCurve var4;
         ECPoint var5;
         BigInteger var6;
         DERObjectIdentifier var7;
         String var8;
         if ((var3 = ECUtil.getNamedCurveByOid(var7 = (DERObjectIdentifier)var2.getParameters())) == null) {
            ECDomainParameters var10;
            var4 = EC5Util.convertCurve((var10 = ECGOST3410NamedCurves.getByOID(var7)).getCurve(), var10.getSeed());
            ECDomainParameters var10003 = var10;
            var8 = ECGOST3410NamedCurves.getName(var7);
            var5 = new ECPoint.<init>(var10.getG().getX().toBigInteger(), var10.getG().getY().toBigInteger());
            var12 = var10.getN();
            var6 = var10003.getH();
            this.ecSpec = new ECNamedCurveSpec(var8, var4, var5, var12, var6);
         } else {
            var4 = EC5Util.convertCurve(var3.getCurve(), var3.getSeed());
            X9ECParameters var14 = var3;
            var8 = ECUtil.getCurveName(var7);
            var5 = new ECPoint.<init>(var3.getG().getX().toBigInteger(), var3.getG().getY().toBigInteger());
            var12 = var3.getN();
            var6 = var14.getH();
            this.ecSpec = new ECNamedCurveSpec(var8, var4, var5, var12, var6);
         }
      } else if (var2.isImplicitlyCA()) {
         this.ecSpec = null;
      } else {
         X9ECParameters var10001 = var3 = new X9ECParameters;
         var10001.<init>((ASN1Sequence)var2.getParameters());
         EllipticCurve var9 = EC5Util.convertCurve(var10001.getCurve(), var3.getSeed());
         EllipticCurve var15 = var9;
         X9ECParameters var10004 = var3;
         ECPoint var11;
         var11 = new ECPoint.<init>(var3.getG().getX().toBigInteger(), var3.getG().getY().toBigInteger());
         var12 = var3.getN();
         int var13 = var10004.getH().intValue();
         this.ecSpec = new ECParameterSpec(var15, var11, var12, var13);
      }

      if (info.getPrivateKey() instanceof DERInteger) {
         this.d = ((DERInteger)info.getPrivateKey()).getValue();
      } else {
         this.d = (new ECPrivateKeyStructure((ASN1Sequence)info.getPrivateKey())).getKey();
      }

   }

   public String getAlgorithm() {
      return this.algorithm;
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      ECParameterSpec var1;
      X962Parameters var2;
      DERObjectIdentifier var6;
      X962Parameters var7;
      if ((var1 = this.ecSpec) instanceof ECNamedCurveSpec) {
         var6 = ECUtil.getNamedCurveOid(((ECNamedCurveSpec)var1).getName());
         var2 = new X962Parameters.<init>(var6);
         var7 = var2;
      } else if (var1 == null) {
         var2 = new X962Parameters.<init>(DERNull.INSTANCE);
         var7 = var2;
      } else {
         ECCurve var8 = EC5Util.convertCurve(var1.getCurve());
         X9ECParameters var9;
         X9ECParameters var10000 = var9 = new X9ECParameters;
         ECCurve var10001 = var8;
         ECCurve var10005 = var8;
         ECPoint var10 = this.ecSpec.getGenerator();
         cn.com.infosec.math.ec.ECPoint var11 = EC5Util.convertPoint(var10005, var10, this.withCompression);
         BigInteger var3 = this.ecSpec.getOrder();
         BigInteger var4 = BigInteger.valueOf((long)this.ecSpec.getCofactor());
         byte[] var5 = this.ecSpec.getCurve().getSeed();
         var10000.<init>(var10001, var11, var3, var4, var5);
         var7 = new X962Parameters.<init>(var9);
      }

      PrivateKeyInfo var12;
      PrivateKeyInfo var13;
      X962Parameters var10003;
      if (this.algorithm.equals("ECGOST3410")) {
         var13 = var12 = new PrivateKeyInfo;
         var10003 = var7;
         var6 = CryptoProObjectIdentifiers.gostR3410_2001;
         var13.<init>(new AlgorithmIdentifier(var6, var10003.getDERObject()), (new ECPrivateKeyStructure(this.getS())).getDERObject());
      } else {
         var13 = var12 = new PrivateKeyInfo;
         var10003 = var7;
         var6 = X9ObjectIdentifiers.id_ecPublicKey;
         var13.<init>(new AlgorithmIdentifier(var6, var10003.getDERObject()), (new ECPrivateKeyStructure(this.getS())).getDERObject());
      }

      return var12.getDEREncoded();
   }

   public ECParameterSpec getParams() {
      return this.ecSpec;
   }

   public cn.com.infosec.jce.spec.ECParameterSpec getParameters() {
      ECParameterSpec var1;
      return (var1 = this.ecSpec) == null ? null : EC5Util.convertSpec(var1, this.withCompression);
   }

   cn.com.infosec.jce.spec.ECParameterSpec engineGetSpec() {
      ECParameterSpec var1;
      return (var1 = this.ecSpec) != null ? EC5Util.convertSpec(var1, this.withCompression) : ProviderUtil.getEcImplicitlyCa();
   }

   public BigInteger getS() {
      return this.d;
   }

   public BigInteger getD() {
      return this.d;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }

   public void setPointFormat(String style) {
      this.withCompression = "UNCOMPRESSED".equalsIgnoreCase(style) ^ true;
   }

   public boolean equals(Object o) {
      if (!(o instanceof JCEECPrivateKey)) {
         return false;
      } else {
         JCEECPrivateKey o1 = (JCEECPrivateKey)o;
         return this.getD().equals(o1.getD()) && this.engineGetSpec().equals(o1.engineGetSpec());
      }
   }

   public int hashCode() {
      return this.getD().hashCode() ^ this.engineGetSpec().hashCode();
   }
}
